Learn R Programming

impressionist.colors (version 1.0)

get.color: Get color Hex codes from palette.

Description

Provides colors' Hex codes from a specified palette.

Usage

get.color(artist, painting, color)

Arguments

artist

A number indicating artist. Artists have a numeric order in the package. Check palette.summary to see artists numeric order.

painting

A number indicating painting. Paintings have a numeric order in the artist category they belong to. Check palette.summary to see paintings numeric order in each artist category.

color

A numeric vector indicating colors. Colors have a numeric order in the palette they belong to. Check see.palette to see colors numeric order in a specified palette.

Value

The output is a vector of colors' Hex codes as characters.

Details

Arguments artist and painting cannot be vectorized.

See Also

palette.summary, see.all.paintings, see.palette

Examples

Run this code
# NOT RUN {
get.color(artist=8, painting=2, color=c(1:5))
get.color(8, 2, c(1:5))
# }

Run the code above in your browser using DataLab