Learn R Programming

impressionist.colors (version 1.0)

palette.summary: Summary of all available palettes in the package.

Description

Prints a summary of all available color palettes in the package categorized by artist and painting along with their numeric order.

Usage

palette.summary()

Arguments

See Also

see.all.paintings, see.palette, get.color,

Examples

Run this code
# NOT RUN {
palette.summary()
# }

Run the code above in your browser using DataLab