Learn R Programming

impressionist.colors (version 1.0)

see.palette: See a color palette with the original painting.

Description

Displays a plot with the specified color palette along with the original painting.

Usage

see.palette(artist, painting)

Arguments

artist

A number indicating artist. Artists have a number determined by their order in the package. Check palette.summary to see artists numeric order.

painting

A number indicating painting. Paintings have a number determined by their order in the artist category. Check palette.summary to see paintings numeric order in each artist category.

Details

Arguments artist and painting cannot be vectorized.

See Also

palette.summary, see.all.paintings, get.color

Examples

Run this code
# NOT RUN {
see.palette(artist=8, painting=2)
see.palette(8, 2)
# }

Run the code above in your browser using DataLab