powered by
Prints a summary of all available color palettes in the package categorized by artist and painting along with their numeric order.
palette.summary()
see.all.paintings, see.palette, get.color,
# NOT RUN { palette.summary() # }
Run the code above in your browser using DataLab